import { producePreset } from "create";
import prettier from "prettier";
import { presetCommon } from "../../../next/presetCommon.js";
import { presetEverything } from "../../../next/presetEverything.js";
import { presetMinimal } from "../../../next/presetMinimal.js";
import { createDotGitHub } from "./dotGitHub/index.js";
import { createDotHusky } from "./dotHusky.js";
import { createDotVSCode } from "./dotVSCode.js";
import { createRootFiles } from "./rootFiles.js";
import { createSrc } from "./src.js";
const presets = {
  common: presetCommon,
  everything: presetEverything,
  minimal: presetMinimal
};
async function createStructure(options, useNextEngine) {
  const preset = useNextEngine && options.base && options.base !== "prompt" && presets[options.base];
  if (preset) {
    const { creation } = await producePreset(preset, {
      mode: "initialize",
      options
    });
    return await recursivelyFormat(creation.files);
  }
  return {
    ".github": await createDotGitHub(options),
    ".husky": createDotHusky(),
    ".vscode": await createDotVSCode(options),
    ...options.mode !== "migrate" && { src: await createSrc(options) },
    ...await createRootFiles(options)
  };
}
async function recursivelyFormat(files) {
  const result = {};
  for (const [key, value] of Object.entries(files)) {
    if (Array.isArray(value)) {
      result[key] = await formatCreatedFile(key, value[0]);
    } else if (typeof value === "string") {
      result[key] = await formatCreatedFile(key, value);
    } else if (typeof value === "object") {
      result[key] = await recursivelyFormat(value);
    }
  }
  return result;
}
const asYaml = /* @__PURE__ */ new Set([
  ".gitignore",
  ".markdownlintignore",
  ".nvmrc",
  ".prettierignore",
  "pre-commit"
]);
async function formatCreatedFile(filepath, entry) {
  if (filepath.endsWith(".yml")) {
    return entry;
  }
  return await prettier.format(entry, {
    useTabs: true,
    ...asYaml.has(filepath) ? { parser: "yaml" } : { filepath }
  });
}
export {
  createStructure
};
//# sourceMappingURL=index.js.map